# Basic 1 compartment PK model with 1st order absorption
# No lag time
# Additive residual error model
# No covariates
#
# Consideration of NONMEM, MONOLIX, NLMIXR

rm(list=ls())
library(IQRtools)
IQRinitCompliance("example_1.R")

# Load structural model
model <- IQRmodel("example_1_model.txt")

# OPTION 1: Define dataset by path
data <- data_IQRest(
  datafile = "example_1_data.csv",
  covNames = c("WT0"), # Vector defining continuous candidate covariate columns in dataset
  catNames = c("SEX"), # Vector defining categorical candidate covariate columns in dataset
  regressorNames = NULL
)

# OPTION 2: Define dataset by data.frame
dataset <- IQRloadCSVdata("example_1_data.csv")
# Option 2 allows modification of the dataset prior to using in the estimation ...

data <- data_IQRest(
  datafile = dataset, 
  covNames = c("WT0"),
  catNames = c("SEX"),
  regressorNames = NULL
)

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type="BOLUS")
)

# Define model specification
modelSpec <- modelSpec_IQRest(
  # Define initial guesses for fixed effects
  # And names of the parameters to be considered for estimation
  POPvalues0      = c(ka=1,   CL=1,   Vc=10),
  
  # Define if fixed effect is estimated or not
  # 1: estimate it, 
  # 0: keep it fixed on initial guess
  POPestimate     = c(ka=1,   CL=1,   Vc=1),

  # Define the distribution of the individual parameters
  # N: normally distributed (positive and negative values possible)
  # L: log-normally distributed (positive values only)
  # G: logit-normally distributed (between 0 and 1 only)
  IIVdistribution = c(ka="L", CL="L", Vc="L"),
  
  # Define initial guesses for the random effects (standard deviation)
  IIVvalues0      = c(ka=0.5, CL=0.5, Vc=0.5),
  
  # Define if random effect is estimated or not
  # 1: estimate it, 
  # 2: keep it fixed on initial guess, 
  # 0: no random effect (independent of IIVvalues0 setting)
  IIVestimate     = c(ka=1,   CL=1,   Vc=1),
  
  # Define error model - 3 options available
  # OUTPUT1 = c("abs",0.3) - additive with initial guess of sd
  # OUTPUT1 = c("rel",1) - proportional with initial guess of sd
  # OUTPUT1 = c("absrel",0.3,1) - additive-proportional with initial guesss of sd for add and prop part
  errorModel = list(
    OUTPUT1 = c("abs",0.3)
  )
)

# Generate estimation object (tool independent)
est <- IQRnlmeEst(model,dosing,data,modelSpec)

# Generate models in NLMIXR, NONMEM, MONOLIX
# IQRnlmeProject(
#   est,
#   projectPath = "Models/MODEL_01_NLMIXR",
#   tool = "NLMIXR",
#   comment="NLMIXR - no lag time, add error, no covariates"
# )

IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_01_NONMEM",
  tool = "NONMEM",
  comment="NONMEM - no lag time, add error, no covariates"
)

IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_01_MONOLIX",
  tool = "MONOLIX",
  comment="MONOLIX - no lag time, add error, no covariates"
)

# Run models in serial
# run_IQRnlmeProject("Models/MODEL_01_NLMIXR")
run_IQRnlmeProject("Models/MODEL_01_NONMEM")
run_IQRnlmeProject("Models/MODEL_01_MONOLIX")


# Generate a multi object with selected NLME projects
pM1 <- as_IQRnlmeProjectMulti(c("Models/MODEL_01_MONOLIX/","Models/MODEL_01_NONMEM/"))

# Generate a multi object with all NLME projects in a given folder
pM2 <- as_IQRnlmeProjectMulti("Models")

# Generate a multi object with all NLME projects in a given folder and subfolders
pM3 <- as_IQRnlmeProjectMulti("..",FLAGrecursive = TRUE)

# Generate summaries
summary(pM1,pathname = "Summary/pM1")
summary(pM2,pathname = "Summary/pM2")

# Generate comparison tables
compareModels_IQRnlmeProjectMulti(pM2)

