# 2 compartmental distribution model with IV infusion
# Consideration of IOV
# Parallel execution of NONMEM run
#
# Consideration of NONMEM only
# IQR Tools does not support IOV modeling with MONOLIX. Main reason is that
# the IOV interpretation in NONMEM is more straight forward and interpretable.

rm(list = ls())
library(IQRtools)
IQRinitCompliance("example_4.R")

# Start from a general dataset format
dg <- IQRdataGENERAL("example_4_dataGeneral.csv")

# Explore the data to see the IOV effect
plotIndiv_IQRdataGENERAL(dg,filename = "indiv_plots.pdf")

# Export as modeling dataset
exportNLME_IQRdataGENERAL(dg,filename = "Data/dataNLME.csv",FLAGxpt = TRUE,FLAGdefine = TRUE)

# Load structural model
model <- IQRmodel("example_4_model.txt")

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type="INFUSION")
)

# Define dataset (do not consider covariates)
data <- data_IQRest(
  datafile = "Data/dataNLME.csv"
)

# Define model specification - including IOV information
modelSpec <- modelSpec_IQRest(
  POPvalues0      = c(CL=0.5,   Vc=3,   Q1=0.5,   Vp1=3),
  POPestimate     = c(CL=1,     Vc=1,   Q1=1,     Vp1=1),

  IIVdistribution = c(CL="L",   Vc="L", Q1="L",   Vp1="L"),

  IIVvalues0      = c(CL=0.3,   Vc=0.3, Q1=0.3,   Vp1=0.3),
  IIVestimate     = c(CL=1,     Vc=1,   Q1=2,     Vp1=1),

  # Define initial guesses for IOV standard deviation
  # Distribution of IOV same as for IIV
  IOVvalues0      = c(CL=0,     Vc=0.2, Q1=0,     Vp1=0.6),
  
  # Define if IOV is estimated
  # 1: estimate it, 
  # 2: keep it fixed on initial guess, 
  # 0: no IOV random effect (independent of IOVvalues0 setting)
  IOVestimate     = c(CL=1,     Vc=1,   Q1=1,     Vp1=1),
  
  errorModel = list(
    OUTPUT1 = c("rel",0.3)
  )
)

# Create estimation object
est <- IQRnlmeEst(model,dosing,data,modelSpec)

# Create NONMEM model
# Note: IOV not handled via MONOLIX
IQRnlmeProject(est = est,
               projectPath = "Models/MODEL_04",
               comment="NONMEM - model with IOV, parallel NONMEM execution",
               tool = "NONMEM",
               algOpt.NRCHAINS = 10,
               algOpt.NONMEM.COVSTEP_MATRIX = "R"
)

# Run NONMEM model with IOV
run_IQRnlmeProject("Models/MODEL_04",Nparallel = 4)
