# 2 compartmental distribution model with first order absorption
# Definition of covariates
#
# Consideration of NONMEM only
# MONOLIX supported identically - no difference.

library(IQRtools)
rm(list = ls())
IQRinitCompliance("example_5.R")

# Structural model
model <- IQRmodel("ModelLibraryPK/model_2cpt_linear_abs1.txt")

# Data
data <- data_IQRest(
  datafile = "Data/data.csv",
  covNames = c("HT0", "WT0", "AGE"),
  catNames  = c("SEX")
)

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type = "BOLUS")
)

# Model specification
modelSpec1 <- modelSpec_IQRest(
  
  # Typical subject parameters
  POPvalues0  = c(kabs = 0.25, CL = 30, Vc = 30, Q1 = 25, Vp1 = 2300),
  POPestimate = c(kabs = 1   , CL = 1 , Vc =  1, Q1 =  1, Vp1 =    1),
  
  # Between subject variability
  IIVdistribution = c(kabs ="L" , CL ="L" , Vc ="L" , Q1 ="L" , Vp1 ="L" ),
  IIVvalues0      = c(kabs = 0.5, CL = 0.5, Vc = 0.5, Q1 = 0.5, Vp1 = 0.5),
  IIVestimate     = c(kabs = 1  , CL = 1  , Vc = 1  , Q1 = 1  , Vp1 = 1  ),
  
  # Covariate model
  # Defined by a list with named elements.
  # - names are the parameters on which to add covariates
  # - values are vectors with names of the candidate covariates
  # - IQR Tools implements:
  #   - Continuous covariates by standard power functions: *(cov/REF)^beta
  #      - Default reference value REF: median in the dataset
  #   - Categorical covariates: *exp(betaX*(cat=categoryX))
  #      - Default reference category: smallest numerical category in cat
  # - Use of MU referencing limits options for covariate implementation
  # - It is always possible to code covariate relationships also directly 
  #   into the structural model - but with SAEM care should be taken - e.g.
  #   a covariate coefficient then benefits from variability (fixed) based on 
  #   convergence considerations.
  covariateModel  = list(
    kabs = c("AGE","SEX"),
    CL   = c("SEX","WT0"),
    Vc   = c("SEX")
  ),
  
  # Error model
  errorModel = list(OUTPUT1 = c(type="rel", rel0 = 0.2))
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec1)

proj    <- IQRnlmeProject(
  est,
  comment = "SEX on CL/Vc/kabs, WT0 on CL, AGE on kabs",
  projectPath = "Models/MODEL_05",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

# Run the model
run_IQRnlmeProject(proj,ncores=12)


