# 2 compartmental distribution model with first order absorption
# Definition of covariates
# - Initial guesses for covariate coefficients
# - Estimation or fixing of covariate coefficients
# - Centering of covariates
#
# Consideration of NONMEM only

library(IQRtools)
rm(list = ls())
IQRinitCompliance("example_6.R")

# Structural model
model <- IQRmodel("ModelLibraryPK/model_2cpt_linear_abs1.txt")

# Data
data <- data_IQRest(
  datafile = "Data/data.csv",
  covNames = c("HT0", "WT0", "AGE"),
  catNames  = c("SEX")
)

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type = "BOLUS")
)

# Model specification
modelSpec1 <- modelSpec_IQRest(
  
  # Typical subject parameters
  POPvalues0  = c(kabs = 0.25, CL = 30, Vc = 30, Q1 = 25, Vp1 = 2300),
  POPestimate = c(kabs = 1   , CL = 1 , Vc =  1, Q1 =  1, Vp1 =    1),
  
  # Between subject variability
  IIVdistribution = c(kabs ="L" , CL ="L" , Vc ="L" , Q1 ="L" , Vp1 ="L" ),
  IIVvalues0      = c(kabs = 0.5, CL = 0.5, Vc = 0.5, Q1 = 0.5, Vp1 = 0.5),
  IIVestimate     = c(kabs = 1  , CL = 1  , Vc = 1  , Q1 = 1  , Vp1 = 1  ),
  
  # Covariate model
  covariateModel  = list(
    kabs = c("AGE","SEX"),
    CL   = c("SEX","WT0"),
    Vc   = c("SEX")
  ),
  
  # Covariate coefficient values
  # ----------------------------
  # Initial guesses for covariate coefficients can be provided in the 
  # following manner. In case of multi-level categorical covariates 
  # the same value will be used as starting guess for all levels different
  # from reference.
  covariateModelValues = list(
    kabs = c("AGE"=0.1,"SEX"=2),
    CL   = c("SEX"=2,"WT0"=0.75),
    Vc   = c("SEX"=0.3)
  ),
  
  # Covariate coefficient estimation settings
  # -----------------------------------------
  # Value of 1 means the coefficient is estimated. 
  # Value of 0 means the coefficient is fixed.
  COVestimate = list(
    kabs = c("AGE"=0,"SEX"=1),
    CL   = c("SEX"=1,"WT0"=0),
    Vc   = c("SEX"=1)
  ),
  
  # Covariate centering
  # -------------------
  # Continuous ovariates can be centered around a defined value
  # Categorical covariates can have a defined reference value
  # Continuous covariates that are not centered in this manner will 
  # be centered around the median in the dataset
  # Categorical covariates that are not centered in this manner will 
  # obtain the smallest category value as reference value
  COVcentering = c("WTKG"=70, SEX=1),
  
  # Error model
  errorModel = list(OUTPUT1 = c(type="rel", rel0 = 0.2))
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec1)

proj    <- IQRnlmeProject(
  est,
  comment = "SEX on CL/Vc/kabs, WT0 on CL, AGE on kabs - provided covariate values - centering - fixing some",
  projectPath = "Models/MODEL_06",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

