# 2 compartmental distribution model with first order absorption
# Estimation of correlation of random effects
# - 3 examples included with different settings
#
# Consideration of NONMEM only

library(IQRtools)
rm(list = ls())
IQRinitCompliance("example_7.R")

# Structural model
model <- IQRmodel("ModelLibraryPK/model_2cpt_linear_abs1.txt")

# Data
data <- data_IQRest(
  datafile = "Data/data.csv",
  covNames = c("HT0", "WT0", "AGE"),
  catNames  = c("SEX")
)

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type = "BOLUS")
)


##########################################################################
# Correlation CL/Vc
##########################################################################

# Model specification
modelSpec1 <- modelSpec_IQRest(
  
  # Typical subject parameters
  POPvalues0  = c(kabs = 0.25, CL = 30, Vc = 30, Q1 = 25, Vp1 = 2300),
  POPestimate = c(kabs = 1   , CL = 1 , Vc =  1, Q1 =  1, Vp1 =    1),
  
  # Between subject variability
  IIVdistribution = c(kabs ="L" , CL ="L" , Vc ="L" , Q1 ="L" , Vp1 ="L" ),
  IIVvalues0      = c(kabs = 0.5, CL = 0.5, Vc = 0.5, Q1 = 0.5, Vp1 = 0.5),
  IIVestimate     = c(kabs = 1  , CL = 1  , Vc = 1  , Q1 = 1  , Vp1 = 1  ),
  
  # Covariate model
  covariateModel  = list(
    kabs = c("AGE","SEX"),
    CL   = c("SEX","WT0"),
    Vc   = c("SEX")
  ),
  
  # Covariance model
  # This example will estimate the correlation between random effects of 
  # CL and Vc. Starting guesses cannot be provided - but also are not 
  # really needed as the estimation algorithms can do a good job on their
  # estimation.
  covarianceModel = c("CL,Vc"),
  
  # Error model
  errorModel = list(OUTPUT1 = c(type="rel", rel0 = 0.2))
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec1)

proj    <- IQRnlmeProject(
  est,
  comment = "Correlation of random effects of CL and Vc",
  projectPath = "Models/MODEL_07_1",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

# Run the model
run_IQRnlmeProject(proj,ncores=12)

##########################################################################
# Correlation CL/Vc/Q1
##########################################################################

# Model specification
modelSpec1 <- modelSpec_IQRest(
  
  # Typical subject parameters
  POPvalues0  = c(kabs = 0.25, CL = 30, Vc = 30, Q1 = 25, Vp1 = 2300),
  POPestimate = c(kabs = 1   , CL = 1 , Vc =  1, Q1 =  1, Vp1 =    1),
  
  # Between subject variability
  IIVdistribution = c(kabs ="L" , CL ="L" , Vc ="L" , Q1 ="L" , Vp1 ="L" ),
  IIVvalues0      = c(kabs = 0.5, CL = 0.5, Vc = 0.5, Q1 = 0.5, Vp1 = 0.5),
  IIVestimate     = c(kabs = 1  , CL = 1  , Vc = 1  , Q1 = 1  , Vp1 = 1  ),
  
  # Covariate model
  covariateModel  = list(
    kabs = c("AGE","SEX"),
    CL   = c("SEX","WT0"),
    Vc   = c("SEX")
  ),
  
  # Covariance model
  # This example estmates the correlations between CL/Vc, CL/Q1, Vc/Q1
  # Note that the order of the parameters is not important. It will be handled
  # by IQR Tools internally.
  covarianceModel = c("CL,Vc,Q1"),
  
  # Error model
  errorModel = list(OUTPUT1 = c(type="rel", rel0 = 0.2))
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec1)

proj    <- IQRnlmeProject(
  est,
  comment = "Correlation of random effects of CL/Vc/Q1",
  projectPath = "Models/MODEL_07_2",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

# Run the model
run_IQRnlmeProject(proj,ncores=12)


##########################################################################
# Correlation CL/Vc/Q1 and Vp1/kabs
##########################################################################

# Model specification
modelSpec1 <- modelSpec_IQRest(
  
  # Typical subject parameters
  POPvalues0  = c(kabs = 0.25, CL = 30, Vc = 30, Q1 = 25, Vp1 = 2300),
  POPestimate = c(kabs = 1   , CL = 1 , Vc =  1, Q1 =  1, Vp1 =    1),
  
  # Between subject variability
  IIVdistribution = c(kabs ="L" , CL ="L" , Vc ="L" , Q1 ="L" , Vp1 ="L" ),
  IIVvalues0      = c(kabs = 0.5, CL = 0.5, Vc = 0.5, Q1 = 0.5, Vp1 = 0.5),
  IIVestimate     = c(kabs = 1  , CL = 1  , Vc = 1  , Q1 = 1  , Vp1 = 1  ),
  
  # Covariate model
  covariateModel  = list(
    kabs = c("AGE","SEX"),
    CL   = c("SEX","WT0"),
    Vc   = c("SEX")
  ),
  
  # Covariance model
  # This example estmates the correlations between 
  #  - CL/Vc, CL/Q1, Vc/Q1
  #  - Vp1 and kabs
  covarianceModel = c("CL,Vc,Q1","Vp1,kabs"),
  
  # Error model
  errorModel = list(OUTPUT1 = c(type="rel", rel0 = 0.2))
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec1)

proj    <- IQRnlmeProject(
  est,
  comment = "Correlation of random effects of CL/Vc/Q1 and Vp1/kabs",
  projectPath = "Models/MODEL_07_3",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

# Run the model
run_IQRnlmeProject(proj,ncores=12)
