# Basic 1 compartment PK model with 1st order absorption
# WT0 as covariate on CL - implementation by regressor
#
# Consideration of NONMEM, MONOLIX

rm(list=ls())
library(IQRtools)
IQRinitCompliance("example_9.R")

# Load structural model
model <- IQRmodel("example_9_model.txt")

# Define dataset 
data <- data_IQRest(
  datafile = "example_9_data.csv",
  catNames = c("SEX"), # Vector defining categorical candidate covariate columns in dataset
  regressorNames = c("WT0") # Implementation of covariate as regressor
)

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type="BOLUS")
)

# Define model specification
modelSpec <- modelSpec_IQRest(
  # Implementation of covariate WT0 on CL by regressor in the model
  # Requires definition of covariate coefficient name as normal parameter
  POPvalues0      = c(ka=1,   CL=1,   Vc=10,  betaCLWT0=0.75),
  POPestimate     = c(ka=1,   CL=1,   Vc=1,   betaCLWT0=1),
  # If sign for betaCLWT0 is known it is beneficial to implement it as 
  # positive parameter, choosing "L" as distribution
  IIVdistribution = c(ka="L", CL="L", Vc="L", betaCLWT0="L"),
  # Small IIV (here 5CV%) for betaCLWT0 - improves convergence 
  IIVvalues0      = c(ka=0.5, CL=0.5, Vc=0.5, betaCLWT0=0.05),
  # Do not estimate the IIV for betaCLWT0
  IIVestimate     = c(ka=1,   CL=1,   Vc=1,   betaCLWT0=2),
  errorModel = list(
    OUTPUT1 = c("abs",0.3)
  )
)

# Generate estimation object (tool independent)
est <- IQRnlmeEst(model,dosing,data,modelSpec)

# Generate models in NONMEM and MONOLIX
IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_09_NONMEM",
  tool = "NONMEM",
  comment="NONMEM - covariate implemented as regressor"
)

IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_09_MONOLIX",
  tool = "MONOLIX",
  comment="MONOLIX - covariate implemented as regressor"
)

# Run model
run_IQRnlmeProject("Models/MODEL_09_NONMEM")
run_IQRnlmeProject("Models/MODEL_09_MONOLIX")

